@@ -75,10 +75,10 @@ enum {
 	PROP_INSERT_SPACES,
 	PROP_SHOW_MARGIN,
 	PROP_MARGIN,
-	PROP_SMART_HOME_END
+	PROP_SMART_HOME_END,
+	PROP_HIGHLIGHT_CURRENT_LINE
 };
 
-
 struct _GtkSourceViewPrivate
 {
 	guint		 tabs_width;
@@ -87,6 +87,7 @@ struct _GtkSourceViewPrivate
 	gboolean	 auto_indent;
 	gboolean	 insert_spaces;
 	gboolean	 show_margin;
+	gboolean	 highlight_current_line;
 	guint		 margin;
 	gint             cached_margin_width;
 	gboolean	 smart_home_end;
@@ -142,10 +143,8 @@ static void 	gtk_source_view_get_lines 		(GtkTextView       *text_view,
 				       			 gint              *countp);
 static gint     gtk_source_view_expose 			(GtkWidget         *widget,
 							 GdkEventExpose    *event);
-
-static gint	key_press_cb 				(GtkWidget         *widget, 
-							 GdkEventKey       *event, 
-							 gpointer           data);
+static gboolean	key_press_event				(GtkWidget         *widget, 
+							 GdkEventKey       *event);
 static void 	view_dnd_drop 				(GtkTextView       *view, 
 							 GdkDragContext    *context,
 							 gint               x,
@@ -189,7 +188,8 @@ gtk_source_view_class_init (GtkSourceViewClass *klass)
 	object_class->finalize = gtk_source_view_finalize;
 	object_class->get_property = gtk_source_view_get_property;
 	object_class->set_property = gtk_source_view_set_property;
-	
+
+	widget_class->key_press_event = key_press_event;
 	widget_class->expose_event = gtk_source_view_expose;
 	widget_class->style_set = gtk_source_view_style_set;
 
@@ -247,7 +247,7 @@ gtk_source_view_class_init (GtkSourceViewClass *klass)
 							       _("Whether to display the right margin"),
 							       FALSE,
 							       G_PARAM_READWRITE));
-
+	
 	g_object_class_install_property (object_class,
 					 PROP_MARGIN,
 					 g_param_spec_uint ("margin",
@@ -262,10 +262,20 @@ gtk_source_view_class_init (GtkSourceViewClass *klass)
 					 PROP_SMART_HOME_END,
 					 g_param_spec_boolean ("smart_home_end",
 							       _("Use smart home/end"),
-							       _("HOME and END keys move to first/last characters on line first before going to the start/end of the line"),
+							       _("HOME and END keys move to first/last "
+								 "non whitespace characters on line before going "
+								 "to the start/end of the line"),
 							       TRUE,
 							       G_PARAM_READWRITE));
 
+	g_object_class_install_property (object_class,
+					 PROP_HIGHLIGHT_CURRENT_LINE,
+					 g_param_spec_boolean ("highlight_current_line",
+							       _("Highlight current line"),
+							       _("Whether to highlight the current line"),
+							       FALSE,
+							       G_PARAM_READWRITE));
+
 	signals [UNDO] =
 		g_signal_new ("undo",
 			      G_TYPE_FROM_CLASS (klass),
@@ -297,6 +307,10 @@ gtk_source_view_class_init (GtkSourceViewClass *klass)
 				      GDK_z,
 				      GDK_CONTROL_MASK | GDK_SHIFT_MASK,
 				      "redo", 0);
+	gtk_binding_entry_add_signal (binding_set,
+				      GDK_F14,
+				      0,
+				      "undo", 0);
 }
 
 static void 
@@ -353,6 +367,12 @@ gtk_source_view_set_property (GObject      *object,
 			gtk_source_view_set_smart_home_end (view,
 							    g_value_get_boolean (value));
 			break;
+
+		case PROP_HIGHLIGHT_CURRENT_LINE:
+			gtk_source_view_set_highlight_current_line (view,
+								    g_value_get_boolean (value));
+			break;
+
 		
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -419,6 +439,10 @@ gtk_source_view_get_property (GObject    *object,
 					     gtk_source_view_get_smart_home_end (view));
 			break;
 			
+		case PROP_HIGHLIGHT_CURRENT_LINE:
+			g_value_set_boolean (value,
+					     gtk_source_view_get_highlight_current_line (view));
+
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -444,11 +468,6 @@ gtk_source_view_init (GtkSourceView *view)
 	gtk_text_view_set_left_margin (GTK_TEXT_VIEW (view), 2);
 	gtk_text_view_set_right_margin (GTK_TEXT_VIEW (view), 2);
 
-	g_signal_connect (G_OBJECT (view),
-			  "key_press_event",
-			  G_CALLBACK (key_press_cb),
-			  NULL);
-
 	tl = gtk_drag_dest_get_target_list (GTK_WIDGET (view));
 	g_return_if_fail (tl != NULL);
 
@@ -612,50 +631,37 @@ set_source_buffer (GtkSourceView *view, GtkTextBuffer *buffer)
 	}
 }
 
-static void
-scroll_to_cursor (GtkSourceView *view)
-{
-	GtkTextBuffer* buffer = NULL;
-	
-	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
-	g_return_if_fail (buffer != NULL);
-
-	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (view),
-				gtk_text_buffer_get_mark (buffer,
-				"insert"));
-}
-
 static void
 gtk_source_view_undo (GtkSourceView *view)
 {
-	GtkSourceBuffer *buffer;
-	
+	GtkTextBuffer *buffer;
+
 	g_return_if_fail (GTK_IS_SOURCE_VIEW (view));
 
-	buffer = GTK_SOURCE_BUFFER (
-			gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
-		
-	if (gtk_source_buffer_can_undo (buffer))
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
+
+	if (gtk_source_buffer_can_undo (GTK_SOURCE_BUFFER (buffer)))
 	{
-		gtk_source_buffer_undo (buffer);
-		scroll_to_cursor (view);
+		gtk_source_buffer_undo (GTK_SOURCE_BUFFER (buffer));
+		gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (view),
+						    gtk_text_buffer_get_insert (buffer));
 	}
 }
 
 static void
 gtk_source_view_redo (GtkSourceView *view)
 {
-	GtkSourceBuffer *buffer;
+	GtkTextBuffer *buffer;
 
 	g_return_if_fail (GTK_IS_SOURCE_VIEW (view));
 
-	buffer = GTK_SOURCE_BUFFER (
-			gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
-		
-	if (gtk_source_buffer_can_redo (buffer))
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
+
+	if (gtk_source_buffer_can_redo (GTK_SOURCE_BUFFER (buffer)))
 	{
-		gtk_source_buffer_redo (buffer);
-		scroll_to_cursor (view);
+		gtk_source_buffer_redo (GTK_SOURCE_BUFFER (buffer));
+		gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (view),
+						    gtk_text_buffer_get_insert (buffer));
 	}
 }
 
@@ -968,6 +974,8 @@ gtk_source_view_paint_margin (GtkSourceView *view,
 	gint margin_width;
 	gint text_width, x_pixmap;
 	gint i;
+	GtkTextIter cur;
+	gint cur_line;
 
 	text_view = GTK_TEXT_VIEW (view);
 
@@ -1089,10 +1097,17 @@ gtk_source_view_paint_margin (GtkSourceView *view,
 		marker_line = gtk_source_marker_get_line (
 			GTK_SOURCE_MARKER (current_marker->data));
 	
+	
+	gtk_text_buffer_get_iter_at_mark (text_view->buffer, 
+					  &cur, 
+					  gtk_text_buffer_get_insert (text_view->buffer));
+
+	cur_line = gtk_text_iter_get_line (&cur) + 1;
+	
 	while (i < count) 
 	{
 		gint pos;
-
+		
 		gtk_text_view_buffer_to_window_coords (text_view,
 						       GTK_TEXT_WINDOW_LEFT,
 						       0,
@@ -1102,10 +1117,24 @@ gtk_source_view_paint_margin (GtkSourceView *view,
 
 		if (view->priv->show_line_numbers) 
 		{
-			g_snprintf (str, sizeof (str),
-				    "%d", g_array_index (numbers, gint, i) + 1);
+			gint line_to_paint = g_array_index (numbers, gint, i) + 1;
+			
+			if (line_to_paint == cur_line)
+			{
+				gchar *markup;
+				markup = g_strdup_printf ("<b>%d</b>", line_to_paint);
+				
+				pango_layout_set_markup (layout, markup, -1);
 
-			pango_layout_set_text (layout, str, -1);
+				g_free (markup);
+			}
+			else
+			{
+				g_snprintf (str, sizeof (str),
+					    "%d", line_to_paint);
+
+				pango_layout_set_markup (layout, str, -1);
+			}
 
 			gtk_paint_layout (GTK_WIDGET (view)->style,
 					  win,
@@ -1211,6 +1240,50 @@ gtk_source_view_expose (GtkWidget      *widget,
 				gdk_window_invalidate_rect (w, NULL, FALSE);
 		}
 
+		if (view->priv->highlight_current_line && 
+		    (event->window == gtk_text_view_get_window (text_view, GTK_TEXT_WINDOW_TEXT)))
+		{
+			GdkRectangle visible_rect;
+			GdkRectangle redraw_rect;
+			GtkTextIter cur;
+			gint y;
+			gint height;
+			gint win_y;
+			
+			gtk_text_buffer_get_iter_at_mark (text_view->buffer, 
+							  &cur, 
+							  gtk_text_buffer_get_insert (text_view->buffer));
+
+			gtk_text_view_get_line_yrange (text_view, &cur, &y, &height);
+							
+			gtk_text_view_get_visible_rect (text_view, &visible_rect);
+			
+			gtk_text_view_buffer_to_window_coords (text_view,
+						       GTK_TEXT_WINDOW_TEXT,
+						       visible_rect.x,
+						       visible_rect.y,
+						       &redraw_rect.x,
+						       &redraw_rect.y);
+
+			gtk_text_view_buffer_to_window_coords (text_view,
+						       GTK_TEXT_WINDOW_TEXT,
+						       0,
+						       y,
+						       NULL,
+						       &win_y);
+
+			redraw_rect.width = visible_rect.width;
+			redraw_rect.height = visible_rect.height;
+
+			gdk_draw_rectangle (event->window,
+					    widget->style->bg_gc[GTK_WIDGET_STATE (widget)],
+					    TRUE,
+					    redraw_rect.x + MAX (0, gtk_text_view_get_left_margin (text_view) - 1),
+					    win_y,
+					    redraw_rect.width,
+					    height);
+		}
+
 		if (view->priv->show_margin && 
 		    (event->window == gtk_text_view_get_window (text_view, GTK_TEXT_WINDOW_TEXT)))
 		{
@@ -1246,6 +1319,7 @@ gtk_source_view_expose (GtkWidget      *widget,
 					 gtk_text_view_get_left_margin (text_view));
 		}
 
+		
 		if (GTK_WIDGET_CLASS (parent_class)->expose_event)
 			event_handled = 
 				(* GTK_WIDGET_CLASS (parent_class)->expose_event)
@@ -1256,7 +1330,6 @@ gtk_source_view_expose (GtkWidget      *widget,
 	return event_handled;	
 }
 
-
 /*
  *This is a pretty important function...we call it when the tab_stop is changed,
  *And when the font is changed.
@@ -1321,7 +1394,7 @@ gtk_source_view_new ()
 
 /**
  * gtk_source_view_new_with_buffer:
- * @buffer: a #GtkSourceBuffer
+ * @buffer: a #GtkSourceBuffer.
  *
  * Creates a new #GtkSourceView widget displaying the buffer
  * @buffer. One buffer can be shared among many widgets.
@@ -1369,11 +1442,11 @@ gtk_source_view_get_type (void)
 
 /**
  * gtk_source_view_get_show_line_numbers:
- * @view: a #GtkSourceView
+ * @view: a #GtkSourceView.
  *
  * Returns whether line numbers are displayed beside the text.
  *
- * Return value: TRUE if the line numbers are displayed.
+ * Return value: %TRUE if the line numbers are displayed.
  **/
 gboolean
 gtk_source_view_get_show_line_numbers (GtkSourceView *view)
@@ -1386,10 +1459,10 @@ gtk_source_view_get_show_line_numbers (GtkSourceView *view)
 
 /**
  * gtk_source_view_set_show_line_numbers:
- * @view: a #GtkSourceView
- * @show: whether line numbers should be displayed
+ * @view: a #GtkSourceView.
+ * @show: whether line numbers should be displayed.
  *
- * If TRUE line numbers will be displayed beside the text.
+ * If %TRUE line numbers will be displayed beside the text.
  *
  **/
 void
@@ -1436,11 +1509,11 @@ gtk_source_view_set_show_line_numbers (GtkSourceView *view,
 
 /**
  * gtk_source_view_get_show_line_markers:
- * @view: a #GtkSourceView
+ * @view: a #GtkSourceView.
  *
  * Returns whether line markers are displayed beside the text.
  *
- * Return value: TRUE if the line markers are displayed.
+ * Return value: %TRUE if the line markers are displayed.
  **/
 gboolean
 gtk_source_view_get_show_line_markers (GtkSourceView *view)
@@ -1453,10 +1526,10 @@ gtk_source_view_get_show_line_markers (GtkSourceView *view)
 
 /**
  * gtk_source_view_set_show_line_markers:
- * @view: a #GtkSourceView
- * @show: whether line markers should be displayed
+ * @view: a #GtkSourceView.
+ * @show: whether line markers should be displayed.
  *
- * If TRUE line markers will be displayed beside the text.
+ * If %TRUE line markers will be displayed beside the text.
  *
  **/
 void
@@ -1503,7 +1576,7 @@ gtk_source_view_set_show_line_markers (GtkSourceView *view,
 
 /**
  * gtk_source_view_get_tabs_width:
- * @view: a #GtkSourceView
+ * @view: a #GtkSourceView.
  *
  * Returns the width of tabulation in characters.
  *
@@ -1542,8 +1615,8 @@ set_tab_stops_internal (GtkSourceView *view)
 
 /**
  * gtk_source_view_set_tabs_width:
- * @view: a #GtkSourceView
- * @width: width of tab in characters
+ * @view: a #GtkSourceView.
+ * @width: width of tab in characters.
  *
  * Sets the width of tabulation in characters.
  *
@@ -1578,11 +1651,11 @@ gtk_source_view_set_tabs_width (GtkSourceView *view,
 
 /**
  * gtk_source_view_set_marker_pixbuf:
- * @view: a #GtkSourceView
- * @marker_type: 
- * @pixbuf:
- *
+ * @view: a #GtkSourceView.
+ * @marker_type: a marker type.
+ * @pixbuf: a #GdkPixbuf.
  *
+ * Associates a given @pixbuf with a given @marker_type.
  **/
 void
 gtk_source_view_set_marker_pixbuf (GtkSourceView *view,
@@ -1628,10 +1701,12 @@ gtk_source_view_set_marker_pixbuf (GtkSourceView *view,
 
 /**
  * gtk_source_view_get_marker_pixbuf:
- * @view: a #GtkSourceView
- * @marker_type: 
+ * @view: a #GtkSourceView.
+ * @marker_type: a marker type. 
  *
- * Return value:
+ * Gets the pixbuf which is associated with the given @marker_type.
+ *
+ * Return value: a #GdkPixbuf if found, or %NULL if not found.
  **/
 GdkPixbuf * 
 gtk_source_view_get_marker_pixbuf (GtkSourceView *view,
@@ -1651,21 +1726,30 @@ gtk_source_view_get_marker_pixbuf (GtkSourceView *view,
 	return pixbuf;
 }
 
-static gchar*
-compute_indentation (GtkSourceView *view, gint line)
+static gchar *
+compute_indentation (GtkSourceView *view, 
+		     GtkTextIter   *cur)
 {
 	GtkTextIter start;
 	GtkTextIter end;
-	gunichar ch;
 
-	gtk_text_buffer_get_iter_at_line (
-			gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)), 
-			&start, line);
+	gunichar ch;
+	gint line;
+
+	line = gtk_text_iter_get_line (cur);
+
+	gtk_text_buffer_get_iter_at_line (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)), 
+					  &start, 
+					  line);
 
 	end = start;
 
 	ch = gtk_text_iter_get_char (&end);
-	while (g_unichar_isspace (ch) && ch != '\n' && ch != '\r')
+
+	while (g_unichar_isspace (ch) && 
+	       (ch != '\n') && 
+	       (ch != '\r') && 
+	       (gtk_text_iter_compare (&end, cur) < 0))
 	{
 		if (!gtk_text_iter_forward_char (&end))
 			break;
@@ -1679,8 +1763,8 @@ compute_indentation (GtkSourceView *view, gint line)
 	return gtk_text_iter_get_slice (&start, &end);
 }
 
-static gint
-key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
+static gboolean
+key_press_event (GtkWidget *widget, GdkEventKey *event)
 {
 	GtkSourceView *view;
 	GtkTextBuffer *buf;
@@ -1695,21 +1779,31 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
 
 	mark = gtk_text_buffer_get_insert (buf);
 	gtk_text_buffer_get_iter_at_mark (buf, &cur, mark);
-	
-	if ((key == GDK_Return) && view->priv->auto_indent)
+
+	if ((key == GDK_Return) && !(event->state & GDK_SHIFT_MASK) && view->priv->auto_indent)
 	{
 		/* Auto-indent means that when you press ENTER at the end of a
 		 * line, the new line is automatically indented at the same
 		 * level as the previous line.
+		 * SHIFT+ENTER allows to avoid autoindentation.
 		 */
 		gchar *indent = NULL;
 
 		/* Calculate line indentation and create indent string. */
-		indent = compute_indentation (view, 
-					      gtk_text_iter_get_line (&cur));
+		indent = compute_indentation (view, &cur);
 
 		if (indent != NULL)
 		{
+			/* Allow input methods to internally handle a key press event. 
+			 * If this function returns TRUE, then no further processing should be done 
+			 * for this keystroke. */
+			if (gtk_im_context_filter_keypress (GTK_TEXT_VIEW(view)->im_context, event))
+				return TRUE;
+
+			/* If an input method has inserted some test while handling the key press event,
+			 * the cur iterm may be invalid, so get the iter again */
+			gtk_text_buffer_get_iter_at_mark (buf, &cur, mark);
+	
 			/* Insert new line and auto-indent. */
 			gtk_text_buffer_begin_user_action (buf);
 			gtk_text_buffer_insert (buf, &cur, "\n", 1);
@@ -1717,7 +1811,7 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
 			g_free (indent);
 			gtk_text_buffer_end_user_action (buf);
 			gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (widget),
-							    gtk_text_buffer_get_insert (buf));
+							    mark);
 			return TRUE;
 		}
 	}
@@ -1748,17 +1842,17 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
 
 		return TRUE;
 	}
-		
-	return FALSE;
+
+	return	(* GTK_WIDGET_CLASS (parent_class)->key_press_event) (widget, event);
 }
 
 /**
  * gtk_source_view_get_auto_indent:
- * @view: a #GtkSourceView
+ * @view: a #GtkSourceView.
  *
  * Returns whether auto indentation of text is enabled.
  *
- * Return value: TRUE if auto indentation is enabled.
+ * Return value: %TRUE if auto indentation is enabled.
  **/
 gboolean
 gtk_source_view_get_auto_indent (GtkSourceView *view)
@@ -1770,10 +1864,10 @@ gtk_source_view_get_auto_indent (GtkSourceView *view)
 
 /**
  * gtk_source_view_set_auto_indent:
- * @view: a #GtkSourceView
- * @enable: whether to enable auto indentation
+ * @view: a #GtkSourceView.
+ * @enable: whether to enable auto indentation.
  *
- * If TRUE auto indentation of text is enabled.
+ * If %TRUE auto indentation of text is enabled.
  *
  **/
 void
@@ -1793,12 +1887,12 @@ gtk_source_view_set_auto_indent (GtkSourceView *view, gboolean enable)
 
 /**
  * gtk_source_view_get_insert_spaces_instead_of_tabs:
- * @view: a #GtkSourceView
+ * @view: a #GtkSourceView.
  *
  * Returns whether when inserting a tabulator character it should
  * be replaced by a group of space characters.
  *
- * Return value: TRUE if spaces are inserted instead of tabs.
+ * Return value: %TRUE if spaces are inserted instead of tabs.
  **/
 gboolean
 gtk_source_view_get_insert_spaces_instead_of_tabs (GtkSourceView *view)
@@ -1810,10 +1904,10 @@ gtk_source_view_get_insert_spaces_instead_of_tabs (GtkSourceView *view)
 
 /**
  * gtk_source_view_set_insert_spaces_instead_of_tabs:
- * @view: a #GtkSourceView
- * @enable: whether to insert spaces instead of tabs
+ * @view: a #GtkSourceView.
+ * @enable: whether to insert spaces instead of tabs.
  *
- * If TRUE any tabulator character inserted is replaced by a group
+ * If %TRUE any tabulator character inserted is replaced by a group
  * of space characters.
  *
  **/
@@ -1899,11 +1993,11 @@ view_dnd_drop (GtkTextView *view,
 
 /**
  * gtk_source_view_get_show_margin:
- * @view: a #GtkSourceView
+ * @view: a #GtkSourceView.
  *
- * Returns whether a margin is displayed
+ * Returns whether a margin is displayed.
  *
- * Return value: TRUE if the margin is showed
+ * Return value: %TRUE if the margin is showed.
  **/
 gboolean 
 gtk_source_view_get_show_margin (GtkSourceView *view)
@@ -1915,11 +2009,10 @@ gtk_source_view_get_show_margin (GtkSourceView *view)
 
 /**
  * gtk_source_view_set_show_margin:
- * @view: a #GtkSourceView
- * @show: whether to show a margin
- *
- * If TRUE a margin is displayed
+ * @view: a #GtkSourceView.
+ * @show: whether to show a margin.
  *
+ * If %TRUE a margin is displayed
  **/
 void 
 gtk_source_view_set_show_margin (GtkSourceView *view, gboolean show)
@@ -1939,12 +2032,52 @@ gtk_source_view_set_show_margin (GtkSourceView *view, gboolean show)
 }
 
 /**
- * gtk_source_view_get_margin:
+ * gtk_source_view_get_highlight_current_line:
  * @view: a #GtkSourceView
  *
+ * Returns whether the current line is highlighted
  *
+ * Return value: TRUE if the current line is highlighted
+ **/
+gboolean 
+gtk_source_view_get_highlight_current_line (GtkSourceView *view)
+{
+	g_return_val_if_fail (GTK_IS_SOURCE_VIEW (view), FALSE);
+
+	return view->priv->highlight_current_line;
+}
+
+/**
+ * gtk_source_view_set_highlight_current_line:
+ * @view: a #GtkSourceView
+ * @show: whether to highlight the current line
  *
- * Return value:
+ * If TRUE the current line is highlighted
+ **/
+void 
+gtk_source_view_set_highlight_current_line (GtkSourceView *view, gboolean hl)
+{
+	g_return_if_fail (GTK_IS_SOURCE_VIEW (view));
+
+	hl = (hl != FALSE);
+
+	if (view->priv->highlight_current_line == hl)
+		return;
+
+	view->priv->highlight_current_line = hl;
+
+	gtk_widget_queue_draw (GTK_WIDGET (view));
+
+	g_object_notify (G_OBJECT (view), "highlight_current_line");
+}
+
+/**
+ * gtk_source_view_get_margin:
+ * @view: a #GtkSourceView.
+ *
+ * Gets the position of the right margin in the given @view.
+ *
+ * Return value: the position of the right margin.
  **/
 guint
 gtk_source_view_get_margin  (GtkSourceView *view)
@@ -1957,9 +2090,10 @@ gtk_source_view_get_margin  (GtkSourceView *view)
 
 /**
  * gtk_source_view_set_margin:
- * @view: a #GtkSourceView
- *
+ * @view: a #GtkSourceView.
+ * @margin: the position of the margin to set.
  *
+ * Sets the position of the right margin in the given @view.
  *
  **/
 void 
@@ -1982,10 +2116,10 @@ gtk_source_view_set_margin (GtkSourceView *view, guint margin)
 
 /**
  * gtk_source_view_set_smart_home_end:
- * @view: a #GtkSourceView
- * @enable: whether to enable smart behavior for HOME and END keys
+ * @view: a #GtkSourceView.
+ * @enable: whether to enable smart behavior for HOME and END keys.
  *
- * If TRUE HOME and END keys will move to the first/last non-space
+ * If %TRUE HOME and END keys will move to the first/last non-space
  * character of the line before moving to the start/end.
  *
  **/
@@ -2006,12 +2140,12 @@ gtk_source_view_set_smart_home_end (GtkSourceView *view, gboolean enable)
 
 /**
  * gtk_source_view_get_smart_home_end:
- * @view: a #GtkSourceView
+ * @view: a #GtkSourceView.
  *
  * Returns whether HOME and END keys will move to the first/last non-space
  * character of the line before moving to the start/end.
  *
- * Return value: TRUE if smart behavior for HOME and END keys is enabled
+ * Return value: %TRUE if smart behavior for HOME and END keys is enabled.
  **/
 gboolean
 gtk_source_view_get_smart_home_end (GtkSourceView *view)
@@ -2023,7 +2157,7 @@ gtk_source_view_get_smart_home_end (GtkSourceView *view)
 
 /**
  * gtk_source_view_style_set:
- * @widget: a #GtkSourceView
+ * @widget: a #GtkSourceView.
  * @previous_style:
  *
  *
